import 'slickgrid/slick.compositeeditor.js';
import { CompositeEditorOpenDetailOption, ContainerService, Editor, ExternalResource, GridOption, SlickEventHandler, SlickGrid, SlickDataView } from '@slickgrid-universal/common';
export declare class SlickCompositeEditorComponent implements ExternalResource {
    private _bindEventService;
    private _eventHandler;
    private _modalElm;
    private _originalDataContext;
    private _options;
    private _lastActiveRowNumber;
    private _locales;
    private _formValues;
    private _editors;
    private _editorContainers;
    private _modalBodyTopValidationElm;
    private _modalSaveButtonElm;
    private grid;
    private gridService;
    private gridStateService;
    private translaterService?;
    get eventHandler(): SlickEventHandler;
    get dataView(): SlickDataView;
    get dataViewLength(): number;
    get formValues(): any;
    get editors(): {
        [columnId: string]: Editor;
    };
    set editors(editors: {
        [columnId: string]: Editor;
    });
    get gridOptions(): GridOption;
    constructor();
    /**
     * initialize the Composite Editor by passing the SlickGrid object and the container service
     *
     * Note: we aren't using DI in the constructor simply to be as framework agnostic as possible,
     * we are simply using this init() function with a very basic container service to do the job
     */
    init(grid: SlickGrid, containerService: ContainerService): void;
    /** Dispose of the Component & unsubscribe all events */
    dispose(): void;
    /** Dispose of the Component without unsubscribing any events */
    disposeComponent(): void;
    /**
     * Dynamically change value of an input from the Composite Editor form.
     *
     * NOTE: user might get an error thrown when trying to apply a value on a Composite Editor that was not found in the form,
     * but in some cases the user might still want the value to be applied to the formValues so that it will be sent to the save in final item data context
     * and when that happens, you can just skip that error so it won't throw.
     * @param {String} columnId - column id
     * @param {*} newValue - the new value
     * @param {Boolean} skipMissingEditorError - skipping the error when the Composite Editor was not found will allow to still apply the value into the formValues object
     */
    changeFormInputValue(columnId: string, newValue: any, skipMissingEditorError?: boolean): void;
    /**
     * Dynamically change an Editor option of the Composite Editor form
     * For example, a use case could be to dynamically change the "minDate" of another Date Editor in the Composite Editor form.
     * @param {String} columnId - column id
     * @param {*} newValue - the new value
     */
    changeFormEditorOption(columnId: string, optionName: string, newOptionValue: any): void;
    /**
     * Disable (or enable) an input of the Composite Editor form
     * @param {String} columnId - column definition id
     * @param isDisabled - defaults to True, are we disabling the associated form input
     */
    disableFormInput(columnId: string, isDisabled?: boolean): void;
    /** Entry point to initialize and open the Composite Editor modal window */
    openDetails(options: CompositeEditorOpenDetailOption): SlickCompositeEditorComponent | null;
    /** Cancel the Editing which will also close the modal window */
    cancelEditing(): Promise<void>;
    /** Show a Validation Summary text (as a <div>) when a validation fails or simply hide it when there's no error */
    showValidationSummaryText(isShowing: boolean, errorMsg?: string): void;
    /** Apply Mass Update Changes (form values) to the entire dataset */
    private applySaveMassUpdateChanges;
    /** Apply Mass Changes to the Selected rows in the grid (form values) */
    private applySaveMassSelectionChanges;
    /**
     * Auto-Calculate how many columns to display in the view layout (1, 2, or 3).
     * We'll display a 1 column layout for 8 or less Editors, 2 columns layout for less than 15 Editors or 3 columns when more than 15 Editors
     * @param {number} editorCount - how many Editors do we have in total
     * @returns {number} count - calculated column count (1, 2 or 3)
     */
    private autoCalculateLayoutColumnCount;
    /**
     * Execute the onError callback when defined
     * or use the default onError callback which is to simply display the error in the console
     */
    private executeOnError;
    /**
   * A simple and generic method to execute the "OnSave" callback if it's defined by the user OR else simply execute built-in apply changes callback.
   * This method deals with multiple callbacks as shown below
   * @param {Function} applyChangesCallback - first callback to apply the changes into the grid (this could be a user custom callback)
   * @param {Function} executePostCallback - second callback to execute right after the "onSave"
   * @param {Function} beforeClosingCallback - third and last callback to execute after Saving but just before closing the modal window
   * @param {Object} itemDataContext - item data context, only provided for modal type (create/clone/edit)
   */
    private executeOnSave;
    private focusOnFirstColumnCellWithEditor;
    private findNextAvailableEditorColumnIndex;
    private getActiveCellEditor;
    /**
     * Get the column label, the label might have an optional "columnGroup" (or "columnGroupKey" which need to be translated)
     * @param {object} columnDef - column definition
     * @returns {string} label - column label
     */
    private getColumnLabel;
    /** Get the correct label text depending, if we use a Translater Service then translate the text when possible else use default text */
    private getLabelText;
    /** Retrieve the current selection of row indexes & data context Ids */
    private getCurrentRowSelections;
    private handleBodyClicked;
    private handleKeyDown;
    /** Callback which processes a Mass Update or Mass Selection Changes */
    private handleMassSaving;
    /** Anytime an input of the Composite Editor form changes, we'll add/remove a "modified" CSS className for styling purposes */
    private handleOnCompositeEditorChange;
    /** Check wether the grid has the Row Selection enabled */
    private hasRowSelectionEnabled;
    /** switch case handler to determine which code to execute depending on the modal type */
    private handleSaveClicked;
    /** Insert an item into the DataView or throw an error when finding duplicate id in the dataset */
    private insertNewItemInDataView;
    private parseText;
    /** Put back the current row to its original item data context using the DataView without triggering a change */
    private resetCurrentRowDataContext;
    /** Validate all the Composite Editors that are defined in the form */
    private validateCompositeEditors;
    /** Validate the current cell editor */
    private validateCurrentEditor;
}
